@@ -1,23 +1,9 @@
 /* ============================================================
 *
-* Copyright (C) 2007-2012 by Kåre Särs <kare.sars@iki .fi>
-* Copyright (C) 2014 by Gregor Mitsch: port to KDE5 frameworks
+* SPDX-FileCopyrightText: 2007-2012 Kåre Särs <kare.sars@iki .fi>
+* SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-*  by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License.
-* along with this program.  If not, see <http://www.gnu.org/licenses/>
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 *
 * ============================================================ */
 
@@ -27,7 +13,6 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
-#include <Kdelibs4ConfigMigrator>
 
 #include "skanlite.h"
 
@@ -39,10 +24,6 @@ int main(int argc, char *argv[])
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("Skanlite"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("Skanliterc"));
-    migrate.migrate();
-
     KLocalizedString::setApplicationDomain("skanlite");
 
     KAboutData aboutData(QStringLiteral("skanlite"), // componentName, k4: appName
